@@ -18,6 +18,7 @@ try:
     from PyQt6.QtWidgets import QApplication, QWidget
     from PyQt6.QtGui import QFont, QFontDatabase
     import PyQt6 as PyQt
+
     try:
         from PyQt6 import Qsci
     except ImportError:
@@ -28,6 +29,7 @@ except ImportError:
     from PyQt5.QtWidgets import QApplication, QWidget
     from PyQt5.QtGui import QFont, QFontDatabase
     import PyQt5 as PyQt
+
     try:
         from PyQt5 import Qsci
     except ImportError:
@@ -373,9 +375,9 @@ class McGuiState(QtCore.QObject):
             self.__dataDir = output_dir
         elif simtrace == 1: # trace (mcdisplay)
             if inspect:
-                runstr = mccode_config.configuration["MCDISPLAY"] + ' ' + os.path.basename(self.__instrFile) + ' --no-output-files' + ' --inspect=' + inspect
+                runstr = mccode_config.configuration["MCDISPLAY"] + ' ' + os.path.basename(self.__instrFile) + ' --inspect=' + inspect
             else:
-                runstr = mccode_config.configuration["MCDISPLAY"] + ' ' + os.path.basename(self.__instrFile) + ' --no-output-files'
+                runstr = mccode_config.configuration["MCDISPLAY"] + ' ' + os.path.basename(self.__instrFile)
         else:
             raise Exception('mcgui.run: invalid execution mode (simulate/trace/optimize).')
         
@@ -725,9 +727,13 @@ class McGuiAppController():
             self.emitter.status('Running plotter ...')        
     
     def handleMcDisplayWeb(self):
-        self.emitter.status('Running mcdisplay-webgl...')
+        if mccode_config.configuration["MCCODE"]=="mcstas":
+            DISPLAY="mcdisplay"
+        else:
+            DISPLAY="mxdisplay"
+        self.emitter.status('Running ' + DISPLAY + '-webgl...')
         try:
-            cmd = 'mcdisplay-webgl --default --no-output-files -n100 ' + os.path.basename(self.state.getInstrumentFile()) + '&'
+            cmd = DISPLAY+'-webgl --default -n100 ' + os.path.basename(self.state.getInstrumentFile()) + '&'
             self.emitter.message(cmd, gui=True)
             self.emitter.message('', gui=True)
             
@@ -738,9 +744,13 @@ class McGuiAppController():
             self.emitter.status('')
     
     def handleMcDisplay2D(self):
-        self.emitter.status('Running mcdisplay-webgl...')
+        if mccode_config.configuration["MCCODE"]=="mcstas":
+            DISPLAY="mcdisplay"
+        else:
+            DISPLAY="mxdisplay"
+        self.emitter.status('Running ' + DISPLAY + '-pyqtgraph...')
         try:
-            cmd = 'mcdisplay-pyqtgraph --default --no-output-files -n100 ' + os.path.basename(self.state.getInstrumentFile()) + '&'
+            cmd = DISPLAY+'-pyqtgraph --default -n100 ' + os.path.basename(self.state.getInstrumentFile()) + '&'
             self.emitter.message(cmd, gui=True)
             self.emitter.message('', gui=True)
             
